@@ -25,6 +25,7 @@ def setup_settings(settings, is_prod, **kwargs):
             'invoices/CategoryTree.js',
             'invoices/ContactChoiceField.js',
             'invoices/SelectServiceItemList.js',
+            'invoices/CurrencySelect.js'
         ],
         **settings.get('JS_COMPONENTS', {})
     }
@@ -34,8 +35,21 @@ def setup_settings(settings, is_prod, **kwargs):
     settings['INSTALLED_APPS'] += [
         app for app in [
             'notify',
+            'djmodal',
+            'categories',
+            'products',
             'managers',
-            'invoice_products'
+            'customers',
+            'services',
+            'suppliers',
+            'manufacturers',
+            'history',
+            'stock',
+            'invoice_products',
+            'product_barcode',
+            'notify',
+            'exchange',
+            'tecdoc'
         ] if app not in settings['INSTALLED_APPS']
     ]
 
